<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:ns="http://www.bourse.lu/rap/O11"
	xmlns:ext="java:lu.bourse.api.deposant.action.xsl.XslManager"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:xs="http://www.w3.org/2001/XMLSchema"
	xmlns:fnbcl="http://www.bcl.lu/2006/bcl-xpath-functions"
	xmlns:saxon="http://saxon.sf.net/" extension-element-prefixes="saxon"
	version="2.0">

	<xsl:output method="xml" indent="yes" />
	
	<xsl:variable name="listeTypePart" select="''" as="xs:string"
		saxon:assignable="yes" />

	<xsl:param name="spaceParam" />
	<xsl:param name="ficOri" />
	<xsl:param name="ligneOri" />

	<xsl:template match="/ns:MsgInO11">
		<xsl:apply-templates select="ns:SeqInO11/ns:Conc1" />
	</xsl:template>
	
	<xsl:template match="ns:Conc1">
		<xsl:apply-templates select="ns:Actif" /><!-- ns:Actif avant ns:Context pour d'abord récupérer la liste des categPart -->
		<xsl:apply-templates select="ns:Context" />
		<xsl:apply-templates select="ns:Mt" />
	</xsl:template>

	<xsl:template match="ns:Context">
		<!-- Test CODE DEVISE -->
		<xsl:value-of
			select="ext:testCodDev($ficOri, $ligneOri, 'Code Devise', ns:Dev/ns:CdDevIso, $spaceParam)"
			xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
		
		<xsl:apply-templates select="ns:CollCompartRapO11" />
	</xsl:template>
	
	<xsl:template match="ns:CollCompartRapO11">
		<!-- Test CODES CSSF (FONDS, COMPARTIMENTS) OBLIGATOIRES -->
		<xsl:value-of
			select="ext:testCodesObligatoires($ficOri, $ligneOri, ns:CdCssfOpc, ns:CdCssfCompart, $spaceParam)"
			xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
		
		<!-- Test DATE SUPERIEURE -->
		<xsl:value-of
			select="ext:testDateSuperieureStrict($ficOri, $ligneOri, 'Date de Fin de Période', ns:DtFinRap, 'Date de Début de Période', ns:DtDebRap, 'yyyy-MM-dd', $spaceParam)"
			xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
		
		<!-- Test TAUX CHANGE STRICT POSITIF -->
		<xsl:value-of
			select="ext:testPositifNegatifStrict($ficOri, $ligneOri, 'Taux de Change', format-number(ns:TxChge * 100000, '######'), 'true', 'true', $spaceParam)"
			xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
		
	</xsl:template>
		
	<xsl:template match="ns:Actif">
		<!-- On récupère la liste de tous les CategPart dans le fichier -->
		<xsl:apply-templates select="ns:S120" />
	</xsl:template>

	<xsl:template match="ns:S120">
		<saxon:assign name="listeTypePart"
			select="concat($listeTypePart, ',' , ns:CdCssfCategPart)" />
	</xsl:template>

	<xsl:template match="ns:Mt">
		<!-- Test VALEUR PRODUIT NET DES EMISSIONS POSITIVE ou NULLE -->
		<xsl:value-of
			select="ext:testPositifNegatifStrict($ficOri, $ligneOri, 'Produit Net des Emissions', ns:RapMensO11310/ns:ProdNetEmis310, 'true', 'false', $spaceParam)"
			xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
		
		<!-- Test VALEUR VERSEMENTS EFFECTUES EN REGLEMENT DES ACHATS POSITIVE ou NULLE -->
		<xsl:value-of
			select="ext:testPositifNegatifStrict($ficOri, $ligneOri, 'Versements Effectues en Reglement des Achats', ns:RapMensO11320/ns:Vmt320, 'true', 'false', $spaceParam)"
			xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
		
		<!-- Test VALEUR EMISSIONS NETTES -->
		<xsl:value-of
			select="ext:testEmissionsNettes($ficOri, $ligneOri, ns:RapMensO11310/ns:ProdNetEmis310, 'Produit net des émissions', ns:RapMensO11320/ns:Vmt320, 'Versements effectués en règlement des achats', ns:RapMensO11330/ns:EmisNet330, 'Emissions nettes', $spaceParam)"
			xmlns:spaceParam="java:lu.bourse.services.workflow.Space" />
	</xsl:template>

</xsl:stylesheet>

